Hello community,

here is the log from the commit of package pbzip2 for openSUSE:Factory
checked in at Wed Mar 30 09:32:20 CEST 2011.



--------
--- pbzip2/pbzip2.changes       2011-02-20 00:14:22.000000000 +0100
+++ /mounts/work_src_done/STABLE/pbzip2/pbzip2.changes  2011-03-29 
02:05:46.000000000 +0200
@@ -1,0 +2,10 @@
+Tue Mar 29 00:05:13 UTC 2011 - [email protected]
+
+- update to 1.1.3:
+  * fixes a hang on decompress with --ignore-trailing-garbage=1 when using more
+    than 2 CPUs
+  * the default extension on decompress of .tbz2 has been changed to .tar for
+    bzip2 compatibility
+  * trailing garbage errors will now be printed even when in quiet mode
+
+-------------------------------------------------------------------

calling whatdependson for head-i586


Old:
----
  pbzip2-1.1.2.tar.bz2

New:
----
  pbzip2-1.1.3.tar.bz2

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ pbzip2.spec ++++++
--- /var/tmp/diff_new_pack.t4R8hP/_old  2011-03-30 09:32:10.000000000 +0200
+++ /var/tmp/diff_new_pack.t4R8hP/_new  2011-03-30 09:32:10.000000000 +0200
@@ -18,7 +18,7 @@
 
 
 Name:           pbzip2
-Version:        1.1.2
+Version:        1.1.3
 Release:        1
 %define pkg_version %{version}
 License:        BSD4c

++++++ pbzip2-1.1.2.tar.bz2 -> pbzip2-1.1.3.tar.bz2 ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/AUTHORS new/pbzip2-1.1.3/AUTHORS
--- old/pbzip2-1.1.2/AUTHORS    2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/AUTHORS    2011-03-27 19:10:37.000000000 +0200
@@ -194,6 +194,11 @@
                     - Fixed hang on decompress of some truncated archives (bug 
#590225).
                     - Implemented --ignore-trailing-garbage feature (bug 
#594868)
                     - Fixed hang on decompress of some truncated archives (bug 
#590225)
+                    - Fixed hang on decompress with 
--ignore-trailing-garbage=1 and higher
+                      numCPU (e.g. > 2) (bug #740502)
+                    - Default extension on decompress of .tbz2 changed to .tar 
for
+                      bzip2 compatibility (bug #743639)
+                    - Print trailing garbage errors even when in quiet mode 
(bug #743635)
 
 
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/COPYING new/pbzip2-1.1.3/COPYING
--- old/pbzip2-1.1.2/COPYING    2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/COPYING    2011-03-27 19:10:37.000000000 +0200
@@ -37,4 +37,4 @@
 
 Jeff Gilchrist, Ottawa, Canada.
 [email protected]
-pbzip2 version 1.1.2 of Feb 19, 2011
+pbzip2 version 1.1.3 of Mar 27, 2011
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/ChangeLog new/pbzip2-1.1.3/ChangeLog
--- old/pbzip2-1.1.2/ChangeLog  2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/ChangeLog  2011-03-27 19:10:37.000000000 +0200
@@ -1,3 +1,9 @@
+Changes in 1.1.3 (Mar 27, 2011)
+- Print trailing garbage errors even when in quiet mode (bug #743635)
+- Default extension on decompress of .tbz2 changed to .tar for
+  bzip2 compatibility (bug #743639)
+- Fixed hang on decompress with --ignore-trailing-garbage=1 and higher
+  numCPU (e.g. > 2) (bug #740502)
 Changes in 1.1.2 (Feb 19, 2011)
 - Fix directdecompress segfault when destination file can't be
   opened (e.g. read-only) (bug #717852)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/README new/pbzip2-1.1.3/README
--- old/pbzip2-1.1.2/README     2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/README     2011-03-27 19:10:37.000000000 +0200
@@ -1,6 +1,6 @@
-Feb 19, 2011
+Mar 27, 2011
 
-Parallel BZIP2 v1.1.2 - by: Jeff Gilchrist <[email protected]>
+Parallel BZIP2 v1.1.3 - by: Jeff Gilchrist <[email protected]>
 Available at:  http://compression.ca/
 
 This is the README for pbzip2, a parallel implementation of the
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/pbzip2.1 new/pbzip2-1.1.3/pbzip2.1
--- old/pbzip2-1.1.2/pbzip2.1   2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/pbzip2.1   2011-03-27 19:10:37.000000000 +0200
@@ -1,6 +1,6 @@
 .TH pbzip2 1
 .SH NAME
-pbzip2  \-  parallel bzip2 file compressor, v1.1.2
+pbzip2  \-  parallel bzip2 file compressor, v1.1.3
 .SH SYNOPSIS
 .B pbzip2
 .RB [ " \-123456789 " ]
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/pbzip2.spec new/pbzip2-1.1.3/pbzip2.spec
--- old/pbzip2-1.1.2/pbzip2.spec        2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/pbzip2.spec        2011-03-27 19:10:37.000000000 +0200
@@ -1,5 +1,5 @@
 Name:          pbzip2
-Version:       1.1.2
+Version:       1.1.3
 Release:       1%{?dist}
 Summary:       Parallel implementation of bzip2
 URL:           http://www.compression.ca/pbzip2/
@@ -52,6 +52,9 @@
 
 
 %changelog
+* Sun Mar 27 2011 Jeff Gilchrist <[email protected]> - 1.1.3-1
+- Release 1.1.3
+
 * Sat Feb 19 2011 Jeff Gilchrist <[email protected]> - 1.1.2-1
 - Release 1.1.2
 


++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++



Remember to have fun...

diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/pbzip2-1.1.2/pbzip2.cpp new/pbzip2-1.1.3/pbzip2.cpp
--- old/pbzip2-1.1.2/pbzip2.cpp 2011-02-19 11:10:22.000000000 +0100
+++ new/pbzip2-1.1.3/pbzip2.cpp 2011-03-27 19:10:37.000000000 +0200
@@ -9,7 +9,7 @@
  *           - uses libbzip2 by Julian Seward 
(http://sources.redhat.com/bzip2/)
  *           - Major contributions by Yavor Nikolov 
<[email protected]>
  *
- *     Date  : Feb 19, 2011
+ *     Date  : Mar 27, 2011
  *
  *  TODO
  *  Known Issues
@@ -187,6 +187,11 @@
  *                    - Fixed hang on decompress of some truncated archives 
(bug #590225).
  *                    - Implemented --ignore-trailing-garbage feature (bug 
#594868)
  *                    - Fixed hang on decompress of some truncated archives 
(bug #590225)
+ *                    - Fixed hang on decompress with 
--ignore-trailing-garbage=1 and higher
+ *                      numCPU (e.g. > 2) (bug #740502)
+ *                    - Default extension on decompress of .tbz2 changed to 
.tar for 
+ *                      bzip2 compatibility (bug #743639)
+ *                    - Print trailing garbage errors even when in quiet mode 
(bug #743635)
  *
  *
  *  Specials thanks for suggestions and testing:  Phillippe Welsh,
@@ -243,7 +248,7 @@
  *
  * Jeff Gilchrist, Ottawa, Canada.
  * [email protected]
  * pbzip2 version 1.1.2 of Feb 19, 2011
  *
  */
 #include "pbzip2.h"
@@ -870,10 +875,7 @@
                        if (isTrailingGarbageErr)
                        {
                                // Trailing garbage detected and ignored - not 
a fatal warning
-                               if (QuietMode != 1)
-                               {
-                                       fprintf(stderr, "pbzip2: *WARNING: 
Trailing garbage after EOF ignored!\n");
-                               }
+                               fprintf(stderr, "pbzip2: *WARNING: Trailing 
garbage after EOF ignored!\n");
                                return 1;
                        }
                        else
@@ -1387,6 +1389,7 @@
                {
                        if (consumerDecompressCheckInterrupt(fileData) != 0)
                        {
+                               safe_mutex_unlock(fifo->mut);
                                return (NULL);
                        }
                        
@@ -2966,8 +2969,7 @@
                        }
                        else
                        {
-                               if (QuietMode != 1)
-                                       fprintf(stderr, "pbzip2: *WARNING: 
Trailing garbage after EOF ignored!\n");
+                               fprintf(stderr, "pbzip2: *WARNING: Trailing 
garbage after EOF ignored!\n");
                                return 0;
                        }
                default:
@@ -3188,8 +3190,8 @@
  */
 void banner()
 {
-       fprintf(stderr, "Parallel BZIP2 v1.1.2 - by: Jeff Gilchrist 
[http://compression.ca]\n";);
-       fprintf(stderr, "[Feb. 19, 2011]               (uses libbzip2 by Julian 
Seward)\n");
+       fprintf(stderr, "Parallel BZIP2 v1.1.3 - by: Jeff Gilchrist 
[http://compression.ca]\n";);
+       fprintf(stderr, "[Mar. 27, 2011]               (uses libbzip2 by Julian 
Seward)\n");
        fprintf(stderr, "Major contributions: Yavor Nikolov 
<[email protected]>\n");
 
        return;
@@ -3922,11 +3924,17 @@
 
                        // check if filename ends with .bz2
                        std::string bz2Tail(".bz2");
+                       std::string tbz2Tail(".tbz2");
                        if ( ends_with_icase(outFilename, bz2Tail) )
                        {
                                // remove .bz2 extension
                                outFilename.resize( outFilename.size() - 
bz2Tail.size() );
                        }
+                       else if ( ends_with_icase(outFilename, tbz2Tail) )
+                       {
+                               outFilename.resize( outFilename.size() - 
tbz2Tail.size() );
+                               outFilename += ".tar";
+                       }
                        else
                        {
                                // add .out extension so we don't overwrite 
@@ -243,7 +248,7 @@
  * Jeff Gilchrist, Ottawa, Canada.
  * [email protected]
- * pbzip2 version 1.1.2 of Feb 19, 2011
+ * pbzip2 version 1.1.3 of Mar 27, 2011
  *
  */
original file
-- 
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to